@@ -1,4 +1,4 @@
-package Dist::Zilla::Plugin::Author::Plicease::Init2 2.64 {
+package Dist::Zilla::Plugin::Author::Plicease::Init2 2.65 {
 
   use 5.020;
   use Moose;
@@ -111,7 +111,7 @@ package Dist::Zilla::Plugin::Author::Plicease::Init2 2.64 {
       {
         if($self->type_dzil)
         {
-          return '5.014';
+          return '5.020';
         }
         else
         {
@@ -385,7 +385,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 2.64
+version 2.65
 
 =head1 DESCRIPTION
 
@@ -611,7 +611,8 @@ use base qw( Alien::Base );
 __[ template/Dzil.pm ]__
 use strict;
 use warnings;
-use {{ $perl_version }}
+use {{ $perl_version }};
+use experimental qw( postderef );
 
 package {{ $name =~ s/-/::/gr }} {
 
@@ -887,7 +888,7 @@ on:
   pull_request:
 
 env:
-  PERL5LIB: /cygdrive/c/cx/lib/perl5:/cygdrive/c/cx/lib/perl5/MSWin32-x64-multi-thread
+  PERL5LIB: /cygdrive/c/cx/lib/perl5
   PERL_LOCAL_LIB_ROOT: /cygdrive/cx
   PERL_MB_OPT: --install_base /cygdrive/c/cx
   PERL_MM_OPT: INSTALL_BASE=/cygdrive/c/cx
